@@ -36,8 +36,8 @@ class KigFilterGeogebra : public KigFilter
 {
 public:
     static KigFilterGeogebra* instance();
-    KigDocument* load ( const QString& fromfile );
-    virtual bool supportMime ( const QString& mime );
+    KigDocument* load ( const QString& fromfile ) Q_DECL_OVERRIDE;
+    bool supportMime ( const QString& mime ) Q_DECL_OVERRIDE;
 
 protected:
     KigFilterGeogebra() {}
